Documentation
¶
Index ¶
- type Data
- func (d Data) Channel() uint8
- func (d Data) GetInstrument(stmem note.Semitone) instrument.ID
- func (d Data) GetNote() note.Note
- func (d Data) GetVolume() volume.Volume
- func (d Data) HasCommand() bool
- func (d Data) HasInstrument() bool
- func (d Data) HasNote() bool
- func (d Data) HasVolume() bool
- func (d Data) ShortString() string
- func (d Data) String() string
- type DataEffect
- type InstID
- type Memory
- func (m *Memory) GetPatternLoop() *formatutil.PatternLoop
- func (m *Memory) LastNonZero(input DataEffect) DataEffect
- func (m *Memory) LastNonZeroXY(input DataEffect) (DataEffect, DataEffect)
- func (m *Memory) PortaToNote(input DataEffect) DataEffect
- func (m *Memory) ResetOscillators()
- func (m *Memory) Retrigger()
- func (m *Memory) SampleOffset(input DataEffect) DataEffect
- func (m *Memory) StartOrder()
- func (m *Memory) TempoDecrease(input DataEffect) DataEffect
- func (m *Memory) TempoIncrease(input DataEffect) DataEffect
- func (m *Memory) Tremolo(input DataEffect) (DataEffect, DataEffect)
- func (m *Memory) TremoloOscillator() oscillator.Oscillator
- func (m *Memory) TremorMem() *tremor.Tremor
- func (m *Memory) Vibrato(input DataEffect) (DataEffect, DataEffect)
- func (m *Memory) VibratoOscillator() oscillator.Oscillator
- type SharedMemory
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Data ¶
type Data struct {
What s3mfile.PatternFlags
Note s3mfile.Note
Instrument InstID
Volume s3mfile.Volume
Command uint8
Info DataEffect
}
Data is the data for the channel
func (Data) GetInstrument ¶
func (d Data) GetInstrument(stmem note.Semitone) instrument.ID
GetInstrument returns the instrument for the channel
func (Data) HasCommand ¶
HasCommand returns true if there exists a command on the channel
func (Data) HasInstrument ¶
HasInstrument returns true if there exists an instrument on the channel
func (Data) ShortString ¶
type InstID ¶
type InstID uint8
InstID is an instrument ID in S3M world
type Memory ¶
type Memory struct {
// contains filtered or unexported fields
}
Memory is the storage object for custom effect/command values
func (*Memory) GetPatternLoop ¶
func (m *Memory) GetPatternLoop() *formatutil.PatternLoop
GetPatternLoop returns the pattern loop object from the memory
func (*Memory) LastNonZero ¶
func (m *Memory) LastNonZero(input DataEffect) DataEffect
LastNonZero gets or sets the most recent non-zero value (or input)
func (*Memory) LastNonZeroXY ¶
func (m *Memory) LastNonZeroXY(input DataEffect) (DataEffect, DataEffect)
LastNonZero gets or sets the most recent non-zero value (or input)
func (*Memory) PortaToNote ¶
func (m *Memory) PortaToNote(input DataEffect) DataEffect
PortaToNote gets or sets the most recent non-zero value (or input) for Portamento-to-note
func (*Memory) ResetOscillators ¶
func (m *Memory) ResetOscillators()
ResetOscillators resets the oscillators to defaults
func (*Memory) Retrigger ¶
func (m *Memory) Retrigger()
Retrigger runs certain operations when a note is retriggered
func (*Memory) SampleOffset ¶
func (m *Memory) SampleOffset(input DataEffect) DataEffect
SampleOffset gets or sets the most recent non-zero value (or input) for Sample Offset
func (*Memory) StartOrder ¶
func (m *Memory) StartOrder()
StartOrder is called when the first order's row at tick 0 is started
func (*Memory) TempoDecrease ¶
func (m *Memory) TempoDecrease(input DataEffect) DataEffect
TempoDecrease gets or sets the most recent non-zero value (or input) for Tempo Decrease
func (*Memory) TempoIncrease ¶
func (m *Memory) TempoIncrease(input DataEffect) DataEffect
TempoIncrease gets or sets the most recent non-zero value (or input) for Tempo Increase
func (*Memory) Tremolo ¶
func (m *Memory) Tremolo(input DataEffect) (DataEffect, DataEffect)
Tremolo gets or sets the most recent non-zero value (or input) for Vibrato
func (*Memory) TremoloOscillator ¶
func (m *Memory) TremoloOscillator() oscillator.Oscillator
TremoloOscillator returns the Tremolo oscillator object
func (*Memory) Vibrato ¶
func (m *Memory) Vibrato(input DataEffect) (DataEffect, DataEffect)
Vibrato gets or sets the most recent non-zero value (or input) for Vibrato
func (*Memory) VibratoOscillator ¶
func (m *Memory) VibratoOscillator() oscillator.Oscillator
VibratoOscillator returns the Vibrato oscillator object